
#include"dynamic_cs.h"
int VWdecay=1,VZdecay=1;
